==> teamapps-application-server-0.8-sources.jar: org/teamapps/model/controlcenter/RoleApplicationRoleAssignmentQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface RoleApplicationRoleAssignmentQuery extends Query<RoleApplicationRoleAssignment> {

    static RoleApplicationRoleAssignmentQuery create() {
        return new UdbRoleApplicationRoleAssignmentQuery();
    }

    RoleApplicationRoleAssignmentQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    RoleApplicationRoleAssignmentQuery parseFullTextFilter(String query, String... fieldNames);

	RoleApplicationRoleAssignmentQuery metaCreationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaCreationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaCreatedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaCreatedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaModificationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaModificationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaModifiedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaModifiedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaDeletionDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaDeletionDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaDeletedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaDeletedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaRestoreDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaRestoreDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaRestoredBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaRestoredBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterRole(RoleQuery query);

	RoleApplicationRoleAssignmentQuery role(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orRole(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterApplication(ApplicationQuery query);

	RoleApplicationRoleAssignmentQuery application(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orApplication(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery applicationRoleName(TextFilter filter);

	RoleApplicationRoleAssignmentQuery orApplicationRoleName(TextFilter filter);

	RoleApplicationRoleAssignmentQuery filterOrganizationFieldFilter(OrganizationFieldQuery query);

	RoleApplicationRoleAssignmentQuery organizationFieldFilter(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orOrganizationFieldFilter(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterFixedOrganizationRoot(OrganizationUnitQuery query);

	RoleApplicationRoleAssignmentQuery fixedOrganizationRoot(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orFixedOrganizationRoot(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterOrganizationUnitTypeFilter(OrganizationUnitTypeQuery query);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilter(MultiReferenceFilterType type, OrganizationUnitType ... value);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilterCount(MultiReferenceFilterType type, int count);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilter(MultiReferenceFilter filter);

	RoleApplicationRoleAssignmentQuery orOrganizationUnitTypeFilter(MultiReferenceFilter filter);


    RoleApplicationRoleAssignmentQuery andOr(RoleApplicationRoleAssignmentQuery... queries);

    RoleApplicationRoleAssignmentQuery customFilter(Function<RoleApplicationRoleAssignment, Boolean> customFilter);

    List<RoleApplicationRoleAssignment> execute();

    List<RoleApplicationRoleAssignment> executeOnDeletedRecords();

    RoleApplicationRoleAssignment executeExpectSingleton();

    BitSet executeToBitSet();

    List<RoleApplicationRoleAssignment> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<RoleApplicationRoleAssignment> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}

==> teamapps-application-server-0.14-sources.jar: org/teamapps/model/controlcenter/RoleApplicationRoleAssignmentQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface RoleApplicationRoleAssignmentQuery extends Query<RoleApplicationRoleAssignment> {

    static RoleApplicationRoleAssignmentQuery create() {
        return new UdbRoleApplicationRoleAssignmentQuery();
    }

    RoleApplicationRoleAssignmentQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    RoleApplicationRoleAssignmentQuery parseFullTextFilter(String query, String... fieldNames);

	RoleApplicationRoleAssignmentQuery metaCreationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaCreationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaCreatedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaCreatedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaModificationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaModificationDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaModifiedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaModifiedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaDeletionDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaDeletionDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaDeletedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaDeletedBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaRestoreDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaRestoreDate(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery metaRestoredBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orMetaRestoredBy(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterRole(RoleQuery query);

	RoleApplicationRoleAssignmentQuery role(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orRole(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterApplication(ApplicationQuery query);

	RoleApplicationRoleAssignmentQuery application(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orApplication(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery applicationRoleName(TextFilter filter);

	RoleApplicationRoleAssignmentQuery orApplicationRoleName(TextFilter filter);

	RoleApplicationRoleAssignmentQuery filterOrganizationFieldFilter(OrganizationFieldQuery query);

	RoleApplicationRoleAssignmentQuery organizationFieldFilter(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orOrganizationFieldFilter(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterFixedOrganizationRoot(OrganizationUnitQuery query);

	RoleApplicationRoleAssignmentQuery fixedOrganizationRoot(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery orFixedOrganizationRoot(NumericFilter filter);

	RoleApplicationRoleAssignmentQuery filterOrganizationUnitTypeFilter(OrganizationUnitTypeQuery query);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilter(MultiReferenceFilterType type, OrganizationUnitType ... value);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilterCount(MultiReferenceFilterType type, int count);

	RoleApplicationRoleAssignmentQuery organizationUnitTypeFilter(MultiReferenceFilter filter);

	RoleApplicationRoleAssignmentQuery orOrganizationUnitTypeFilter(MultiReferenceFilter filter);

	RoleApplicationRoleAssignmentQuery noInheritanceOfOrganizationalUnits(BooleanFilter filter);

	RoleApplicationRoleAssignmentQuery orNoInheritanceOfOrganizationalUnits(BooleanFilter filter);


    RoleApplicationRoleAssignmentQuery andOr(RoleApplicationRoleAssignmentQuery... queries);

    RoleApplicationRoleAssignmentQuery customFilter(Function<RoleApplicationRoleAssignment, Boolean> customFilter);

    List<RoleApplicationRoleAssignment> execute();

    List<RoleApplicationRoleAssignment> executeOnDeletedRecords();

    RoleApplicationRoleAssignment executeExpectSingleton();

    BitSet executeToBitSet();

    List<RoleApplicationRoleAssignment> execute(String sortFieldName, boolean ascending, UserContext userContext, String ... path);

    List<RoleApplicationRoleAssignment> execute(int startIndex, int length, Sorting sorting, UserContext userContext);

}
